@@ -998,3 +998,112 @@ def get_module(code: str):
 	assert 'data'in list_result
 	assert 'data' in list_result['data']
 	return None if len(list_result['data']['data']) == 0 else list_result['data']['data'][0]
+
+
+def get_page(code: str):
+	list_response = send_admin_request( 'PageList_Load_Query', {
+		'Filter': [
+			{
+				'name':	'search',
+				'value':
+				[
+					{
+						'field':		'code',
+						'operator':		'EQ',
+						'value':		code
+					}
+				]
+			}
+		]
+	})
+
+	list_result = list_response.json()
+
+	assert list_result['success'] in (True, 1)
+	assert 'data'in list_result
+	assert 'data' in list_result['data']
+	return None if len(list_result['data']['data']) == 0 else merchantapi.model.Page(list_result['data']['data'][0])
+
+
+def reset_branch_state():
+	bllqrequest = merchantapi.request.BranchListLoadQuery(init_client())
+	bllqresponse = bllqrequest.send()
+
+	if len(bllqresponse.get_branches()) == 1:
+		return
+
+	bsprequest = merchantapi.request.BranchSetPrimary(init_client())
+	bsprequest.set_branch_name('Production')
+	bspresponse = bsprequest.send()
+
+	for branch in bllqresponse.get_branches():
+		if branch.get_id() == 1 or branch.get_name() == 'Production':
+			continue
+
+		request = merchantapi.request.BranchDelete(init_client(), branch)
+		response = request.send()
+
+
+def get_css_resource(code: str):
+	list_response = send_admin_request( 'CSSResourceList_Load_Query', {
+		'Filter': [
+			{
+				'name':	'search',
+				'value':
+				[
+					{
+						'field':		'code',
+						'operator':		'EQ',
+						'value':		code
+					}
+				]
+			}
+		]
+	})
+
+	list_result = list_response.json()
+
+	assert list_result['success'] in (True, 1)
+	assert 'data'in list_result
+	assert 'data' in list_result['data']
+	return None if len(list_result['data']['data']) == 0 else merchantapi.model.CSSResource(list_result['data']['data'][0])
+
+
+def get_javascript_resource(code: str):
+	list_response = send_admin_request( 'JavaScriptResourceList_Load_Query', {
+		'Filter': [
+			{
+				'name':	'search',
+				'value':
+				[
+					{
+						'field':		'code',
+						'operator':		'EQ',
+						'value':		code
+					}
+				]
+			}
+		]
+	})
+
+	list_result = list_response.json()
+
+	assert list_result['success'] in (True, 1)
+	assert 'data'in list_result
+	assert 'data' in list_result['data']
+	return None if len(list_result['data']['data']) == 0 else merchantapi.model.JavaScriptResource(list_result['data']['data'][0])
+
+
+def get_price_group_exclusion(priceGroup: str, excudedPriceGroup: str):
+	response = send_admin_request( 'PriceGroupList_Load_Exclusions', {
+		'PriceGroup_Name': priceGroup
+	})
+
+	result = response.json()
+
+	assert result['success'] in (True, 1)
+	assert 'data'in result
+	for pg in result['data']:
+		if pg['name'] == excudedPriceGroup:
+			return pg
+	return None
